" Name:         zaibatsu
" Description:  "If you believe the journalists, he's the single wealthiest individual, period. As rich as some zaibatsu. But there's the catch, really: is he an individual? In the sense that you are, or I am? No." -- William Gibson, Count Zero
" Author:       Romain Lafourcade <romainlafourcade@gmail.com>
" URL:          https://github.com/vim/colorschemes
" License:      Same as Vim
" Last Change:  2025 Oct 08

" Generated by Colortemplate v3.0.0-beta10

set background=dark

hi clear
let g:colors_name = 'zaibatsu'

let s:t_Co = has('gui_running') ? 16777216 : str2nr(&t_Co)
let s:tgc = has('termguicolors') && &termguicolors

let g:terminal_ansi_colors = ['#0e0024', '#d7005f', '#00af5f', '#ffaf00', '#5f5fff', '#d700ff', '#00afff', '#d7d5db', '#878092', '#ff5faf', '#00d700', '#ffd700', '#8787ff', '#ff87ff', '#00ffff', '#ffffff']

hi! link Boolean Constant
hi! link Character Constant
hi! link Conditional Statement
hi! link CurSearch IncSearch
hi! link CursorLineFold CursorLine
hi! link CursorLineNr CursorLine
hi! link CursorLineSign CursorLine
hi! link Define PreProc
hi! link Delimiter Special
hi! link Exception Statement
hi! link Float Constant
hi! link Function Identifier
hi! link Include PreProc
hi! link Keyword Statement
hi! link Label Statement
hi! link LineNrAbove LineNr
hi! link LineNrBelow LineNr
hi! link Macro PreProc
hi! link MessageWindow Pmenu
hi! link Number Constant
hi! link Operator Statement
hi! link PmenuExtraSel PmenuSel
hi! link PmenuKindSel PmenuSel
hi! link PopupNotification Todo
hi! link PreCondit PreProc
hi! link Repeat Statement
hi! link SpecialChar Special
hi! link SpecialComment Special
hi! link StatusLineTerm StatusLine
hi! link StatusLineTermNC StatusLineNC
hi! link StorageClass Type
hi! link String Constant
hi! link Structure Type
hi! link TabLine StatusLineNC
hi! link TabLineFill StatusLineNC
hi! link TabLineSel StatusLine
hi! link Tag Special
hi! link Terminal Normal
hi! link Typedef Type
hi! link lCursor Cursor

hi Normal guifg=#ffffff guibg=#0e0024 guisp=NONE gui=NONE ctermfg=231 ctermbg=16 cterm=NONE term=NONE
hi ColorColumn guifg=NONE guibg=#510039 guisp=NONE gui=NONE ctermfg=NONE ctermbg=52 cterm=NONE term=reverse
hi Comment guifg=#afafff guibg=NONE guisp=NONE gui=NONE ctermfg=147 ctermbg=NONE cterm=NONE term=bold
hi Conceal guifg=NONE guibg=NONE guisp=NONE gui=NONE ctermfg=NONE ctermbg=NONE cterm=NONE term=NONE
hi Constant guifg=#ffff5f guibg=NONE guisp=NONE gui=NONE ctermfg=227 ctermbg=NONE cterm=NONE term=NONE
hi Cursor guifg=#0e0024 guibg=#ffff5f guisp=NONE gui=NONE ctermfg=16 ctermbg=227 cterm=NONE term=reverse
hi CursorColumn guifg=NONE guibg=#362b49 guisp=NONE gui=NONE ctermfg=NONE ctermbg=237 cterm=NONE term=NONE
hi CursorIM guifg=#0e0024 guibg=#ffff5f guisp=NONE gui=NONE ctermfg=16 ctermbg=227 cterm=NONE term=NONE
hi CursorLine guifg=NONE guibg=#362b49 guisp=NONE gui=NONE ctermfg=NONE ctermbg=237 cterm=NONE term=underline
hi DiffAdd guifg=#87ff00 guibg=#362b49 guisp=NONE gui=reverse ctermfg=118 ctermbg=237 cterm=reverse term=reverse
hi DiffChange guifg=#afafff guibg=#362b49 guisp=NONE gui=reverse ctermfg=147 ctermbg=237 cterm=reverse term=NONE
hi DiffDelete guifg=#ff5faf guibg=#362b49 guisp=NONE gui=reverse ctermfg=205 ctermbg=237 cterm=reverse term=reverse
hi DiffText guifg=#d7d5db guibg=#362b49 guisp=NONE gui=reverse ctermfg=189 ctermbg=237 cterm=reverse term=reverse
hi Directory guifg=#87ffff guibg=NONE guisp=NONE gui=NONE ctermfg=123 ctermbg=NONE cterm=NONE term=NONE
hi EndOfBuffer guifg=#afafff guibg=#0e0024 guisp=NONE gui=NONE ctermfg=147 ctermbg=16 cterm=NONE term=NONE
hi Error guifg=#d70000 guibg=#ffffff guisp=NONE gui=reverse ctermfg=160 ctermbg=231 cterm=reverse term=bold,reverse
hi ErrorMsg guifg=#ffffff guibg=#d70000 guisp=NONE gui=NONE ctermfg=231 ctermbg=160 cterm=NONE term=bold,reverse
hi FoldColumn guifg=#00afff guibg=NONE guisp=NONE gui=NONE ctermfg=39 ctermbg=NONE cterm=NONE term=NONE
hi Folded guifg=#ffaf00 guibg=#0e0024 guisp=NONE gui=reverse ctermfg=214 ctermbg=16 cterm=reverse term=NONE
hi Identifier guifg=#87ffff guibg=NONE guisp=NONE gui=NONE ctermfg=123 ctermbg=NONE cterm=NONE term=NONE
hi Ignore guifg=#878092 guibg=NONE guisp=NONE gui=NONE ctermfg=103 ctermbg=NONE cterm=NONE term=NONE
hi IncSearch guifg=#ffaf00 guibg=#0e0024 guisp=NONE gui=reverse ctermfg=214 ctermbg=16 cterm=reverse term=bold,reverse,underline
hi LineNr guifg=#afafff guibg=NONE guisp=NONE gui=NONE ctermfg=147 ctermbg=NONE cterm=NONE term=NONE
hi MatchParen guifg=NONE guibg=NONE guisp=NONE gui=reverse ctermfg=NONE ctermbg=NONE cterm=reverse term=bold,underline
hi ModeMsg guifg=#0e0024 guibg=#87ff00 guisp=NONE gui=NONE ctermfg=16 ctermbg=118 cterm=NONE term=bold
hi MoreMsg guifg=#87ffff guibg=NONE guisp=NONE gui=NONE ctermfg=123 ctermbg=NONE cterm=NONE term=NONE
hi NonText guifg=#878092 guibg=#0e0024 guisp=NONE gui=NONE ctermfg=103 ctermbg=16 cterm=NONE term=NONE
hi Pmenu guifg=#0e0024 guibg=#ffffff guisp=NONE gui=NONE ctermfg=16 ctermbg=231 cterm=NONE term=reverse
hi PmenuExtra guifg=#878092 guibg=#ffffff guisp=NONE gui=NONE ctermfg=103 ctermbg=231 cterm=NONE term=NONE
hi PmenuKind guifg=#878092 guibg=#ffffff guisp=NONE gui=NONE ctermfg=103 ctermbg=231 cterm=NONE term=NONE
hi PmenuMatch guifg=#d700ff guibg=#ffffff guisp=NONE gui=NONE ctermfg=165 ctermbg=231 cterm=NONE term=NONE
hi PmenuMatchSel guifg=#d700ff guibg=#afafff guisp=NONE gui=NONE ctermfg=165 ctermbg=147 cterm=NONE term=NONE
hi PmenuSbar guifg=#d7d5db guibg=#d7d5db guisp=NONE gui=NONE ctermfg=189 ctermbg=189 cterm=NONE term=reverse
hi PmenuSel guifg=#0e0024 guibg=#afafff guisp=NONE gui=NONE ctermfg=16 ctermbg=147 cterm=NONE term=bold
hi PmenuThumb guifg=#878092 guibg=#878092 guisp=NONE gui=NONE ctermfg=103 ctermbg=103 cterm=NONE term=NONE
hi PreProc guifg=#00afff guibg=NONE guisp=NONE gui=NONE ctermfg=39 ctermbg=NONE cterm=NONE term=NONE
hi Question guifg=#87ff00 guibg=NONE guisp=NONE gui=NONE ctermfg=118 ctermbg=NONE cterm=NONE term=standout
hi QuickFixLine guifg=#ffafff guibg=#0e0024 guisp=NONE gui=reverse ctermfg=219 ctermbg=16 cterm=reverse term=NONE
hi Search guifg=#87ffff guibg=#0e0024 guisp=NONE gui=reverse ctermfg=123 ctermbg=16 cterm=reverse term=reverse
hi SignColumn guifg=#00afff guibg=NONE guisp=NONE gui=NONE ctermfg=39 ctermbg=NONE cterm=NONE term=reverse
hi Special guifg=#87ff00 guibg=NONE guisp=NONE gui=NONE ctermfg=118 ctermbg=NONE cterm=NONE term=NONE
hi SpecialKey guifg=#878092 guibg=NONE guisp=NONE gui=NONE ctermfg=103 ctermbg=NONE cterm=NONE term=bold
hi SpellBad guifg=NONE guibg=NONE guisp=#ff5faf gui=undercurl ctermfg=205 ctermbg=NONE cterm=underline term=underline
hi SpellCap guifg=NONE guibg=NONE guisp=#87ff00 gui=undercurl ctermfg=118 ctermbg=NONE cterm=underline term=underline
hi SpellLocal guifg=NONE guibg=NONE guisp=#ffffff gui=undercurl ctermfg=231 ctermbg=NONE cterm=underline term=underline
hi SpellRare guifg=NONE guibg=NONE guisp=#ffafff gui=undercurl ctermfg=219 ctermbg=NONE cterm=underline term=underline
hi Statement guifg=#ffafff guibg=NONE guisp=NONE gui=NONE ctermfg=219 ctermbg=NONE cterm=NONE term=NONE
hi StatusLine guifg=#0e0024 guibg=#ffffff guisp=NONE gui=NONE ctermfg=16 ctermbg=231 cterm=NONE term=bold,reverse
hi StatusLineNC guifg=#0e0024 guibg=#afaab6 guisp=NONE gui=NONE ctermfg=16 ctermbg=146 cterm=NONE term=bold,underline
hi Title guifg=NONE guibg=NONE guisp=NONE gui=NONE ctermfg=NONE ctermbg=NONE cterm=NONE term=NONE
hi TitleBar guifg=#ffffff guibg=#2e2044 guisp=NONE gui=NONE ctermfg=231 ctermbg=237 cterm=NONE term=NONE
hi TitleBarNC guifg=#afaab6 guibg=#1e1034 guisp=NONE gui=NONE ctermfg=146 ctermbg=236 cterm=NONE term=NONE
hi Todo guifg=NONE guibg=NONE guisp=NONE gui=reverse ctermfg=NONE ctermbg=NONE cterm=reverse term=bold,reverse
hi ToolbarButton guifg=#ffffff guibg=#5e556d guisp=NONE gui=NONE ctermfg=231 ctermbg=60 cterm=NONE term=bold,reverse
hi ToolbarLine guifg=NONE guibg=NONE guisp=NONE gui=NONE ctermfg=NONE ctermbg=NONE cterm=NONE term=reverse
hi Type guifg=#ff5faf guibg=NONE guisp=NONE gui=NONE ctermfg=205 ctermbg=NONE cterm=NONE term=NONE
hi Underlined guifg=NONE guibg=NONE guisp=NONE gui=underline ctermfg=NONE ctermbg=NONE cterm=underline term=underline
hi VertSplit guifg=#afafff guibg=NONE guisp=NONE gui=NONE ctermfg=147 ctermbg=NONE cterm=NONE term=NONE
hi Visual guifg=#0e0024 guibg=#5fd7ff guisp=NONE gui=NONE ctermfg=16 ctermbg=81 cterm=NONE term=reverse
hi VisualNOS guifg=#0e0024 guibg=#ffffff guisp=NONE gui=NONE ctermfg=16 ctermbg=231 cterm=NONE term=NONE
hi WarningMsg guifg=#ffafff guibg=NONE guisp=NONE gui=NONE ctermfg=219 ctermbg=NONE cterm=NONE term=standout
hi WildMenu guifg=#0e0024 guibg=#afafff guisp=NONE gui=NONE ctermfg=16 ctermbg=147 cterm=NONE term=bold
hi debugBreakpoint guifg=#87ff00 guibg=#5f00d7 guisp=NONE gui=reverse ctermfg=118 ctermbg=56 cterm=reverse term=reverse
hi debugPC guifg=#87ffff guibg=#5f00d7 guisp=NONE gui=reverse ctermfg=123 ctermbg=56 cterm=reverse term=reverse

if s:tgc || s:t_Co >= 256
  finish
endif

if s:t_Co >= 16
  hi! link PmenuExtraSel PmenuSel
  hi! link PmenuKindSel PmenuSel
  hi Normal ctermfg=white ctermbg=black cterm=NONE
  hi ColorColumn ctermfg=white ctermbg=darkred cterm=NONE
  hi Comment ctermfg=blue ctermbg=NONE cterm=NONE
  hi Conceal ctermfg=NONE ctermbg=NONE cterm=NONE
  hi Constant ctermfg=yellow ctermbg=NONE cterm=NONE
  hi Cursor ctermfg=black ctermbg=yellow cterm=NONE
  hi CursorColumn ctermfg=NONE ctermbg=blue cterm=NONE
  hi CursorIM ctermfg=black ctermbg=yellow cterm=NONE
  hi CursorLine ctermfg=NONE ctermbg=NONE cterm=underline
  hi DiffAdd ctermfg=darkgreen ctermbg=white cterm=reverse
  hi DiffChange ctermfg=darkblue ctermbg=white cterm=reverse
  hi DiffDelete ctermfg=darkmagenta ctermbg=white cterm=reverse
  hi DiffText ctermfg=grey ctermbg=black cterm=reverse
  hi Directory ctermfg=cyan ctermbg=NONE cterm=NONE
  hi EndOfBuffer ctermfg=blue ctermbg=black cterm=NONE
  hi Error ctermfg=red ctermbg=white cterm=reverse
  hi ErrorMsg ctermfg=white ctermbg=red cterm=NONE
  hi FoldColumn ctermfg=darkcyan ctermbg=NONE cterm=NONE
  hi Folded ctermfg=darkyellow ctermbg=black cterm=reverse
  hi Identifier ctermfg=cyan ctermbg=NONE cterm=NONE
  hi Ignore ctermfg=darkgray ctermbg=NONE cterm=NONE
  hi IncSearch ctermfg=darkyellow ctermbg=black cterm=reverse
  hi LineNr ctermfg=blue ctermbg=NONE cterm=NONE
  hi MatchParen ctermfg=NONE ctermbg=NONE cterm=reverse
  hi ModeMsg ctermfg=black ctermbg=green cterm=NONE
  hi MoreMsg ctermfg=cyan ctermbg=NONE cterm=NONE
  hi NonText ctermfg=darkgray ctermbg=black cterm=NONE
  hi Pmenu ctermfg=black ctermbg=white cterm=NONE
  hi PmenuExtra ctermfg=darkgray ctermbg=white cterm=NONE
  hi PmenuKind ctermfg=darkgray ctermbg=white cterm=NONE
  hi PmenuMatch ctermfg=black ctermbg=white cterm=bold
  hi PmenuMatchSel ctermfg=white ctermbg=blue cterm=bold
  hi PmenuSbar ctermfg=gray ctermbg=gray cterm=NONE
  hi PmenuSel ctermfg=white ctermbg=blue cterm=NONE
  hi PmenuThumb ctermfg=darkgray ctermbg=darkgray cterm=NONE
  hi PreProc ctermfg=darkcyan ctermbg=NONE cterm=NONE
  hi Question ctermfg=green ctermbg=NONE cterm=NONE
  hi QuickFixLine ctermfg=magenta ctermbg=black cterm=reverse
  hi Search ctermfg=cyan ctermbg=black cterm=reverse
  hi SignColumn ctermfg=darkcyan ctermbg=NONE cterm=NONE
  hi Special ctermfg=green ctermbg=NONE cterm=NONE
  hi SpecialKey ctermfg=darkgray ctermbg=NONE cterm=NONE
  hi SpellBad ctermfg=red ctermbg=NONE cterm=underline
  hi SpellCap ctermfg=green ctermbg=NONE cterm=underline
  hi SpellLocal ctermfg=white ctermbg=NONE cterm=underline
  hi SpellRare ctermfg=magenta ctermbg=NONE cterm=underline
  hi Statement ctermfg=magenta ctermbg=NONE cterm=NONE
  hi StatusLine ctermfg=white ctermbg=black cterm=reverse
  hi StatusLineNC ctermfg=darkgray ctermbg=gray cterm=reverse
  hi Title ctermfg=NONE ctermbg=NONE cterm=NONE
  hi TitleBar ctermfg=white ctermbg=black cterm=NONE
  hi TitleBarNC ctermfg=gray ctermbg=black cterm=NONE
  hi Todo ctermfg=NONE ctermbg=NONE cterm=reverse
  hi ToolbarButton ctermfg=white ctermbg=darkgray cterm=NONE
  hi ToolbarLine ctermfg=NONE ctermbg=NONE cterm=NONE
  hi Type ctermfg=red ctermbg=NONE cterm=NONE
  hi Underlined ctermfg=NONE ctermbg=NONE cterm=underline
  hi VertSplit ctermfg=blue ctermbg=NONE cterm=NONE
  hi Visual ctermfg=black ctermbg=darkcyan cterm=NONE
  hi VisualNOS ctermfg=black ctermbg=white cterm=NONE
  hi WarningMsg ctermfg=magenta ctermbg=NONE cterm=NONE
  hi WildMenu ctermfg=white ctermbg=blue cterm=NONE
  hi debugBreakpoint ctermfg=green ctermbg=darkblue cterm=reverse
  hi debugPC ctermfg=cyan ctermbg=darkblue cterm=reverse
  finish
endif

if s:t_Co >= 8
  hi! link PmenuExtra Pmenu
  hi! link PmenuExtraSel PmenuSel
  hi! link PmenuKind Pmenu
  hi! link PmenuKindSel PmenuSel
  hi Normal ctermfg=gray ctermbg=black cterm=NONE
  hi ColorColumn ctermfg=white ctermbg=darkred cterm=NONE
  hi Comment ctermfg=blue ctermbg=NONE cterm=NONE
  hi Conceal ctermfg=NONE ctermbg=NONE cterm=NONE
  hi Constant ctermfg=yellow ctermbg=NONE cterm=NONE
  hi Cursor ctermfg=black ctermbg=yellow cterm=NONE
  hi CursorColumn ctermfg=NONE ctermbg=blue cterm=NONE
  hi CursorIM ctermfg=black ctermbg=yellow cterm=NONE
  hi CursorLine ctermfg=NONE ctermbg=NONE cterm=underline
  hi DiffAdd ctermfg=darkgreen ctermbg=white cterm=reverse
  hi DiffChange ctermfg=darkblue ctermbg=white cterm=reverse
  hi DiffDelete ctermfg=darkmagenta ctermbg=white cterm=reverse
  hi DiffText ctermfg=grey ctermbg=black cterm=reverse
  hi Directory ctermfg=cyan ctermbg=NONE cterm=NONE
  hi EndOfBuffer ctermfg=blue ctermbg=black cterm=NONE
  hi Error ctermfg=red ctermbg=white cterm=reverse
  hi ErrorMsg ctermfg=white ctermbg=red cterm=NONE
  hi FoldColumn ctermfg=darkcyan ctermbg=NONE cterm=NONE
  hi Folded ctermfg=darkyellow ctermbg=black cterm=reverse
  hi Identifier ctermfg=cyan ctermbg=NONE cterm=NONE
  hi Ignore ctermfg=darkgray ctermbg=NONE cterm=NONE
  hi IncSearch ctermfg=darkyellow ctermbg=black cterm=reverse
  hi LineNr ctermfg=blue ctermbg=NONE cterm=NONE
  hi MatchParen ctermfg=NONE ctermbg=NONE cterm=reverse
  hi ModeMsg ctermfg=black ctermbg=green cterm=NONE
  hi MoreMsg ctermfg=cyan ctermbg=NONE cterm=NONE
  hi NonText ctermfg=darkgray ctermbg=black cterm=NONE
  hi Pmenu ctermfg=black ctermbg=white cterm=NONE
  hi PmenuMatch ctermfg=black ctermbg=white cterm=bold
  hi PmenuMatchSel ctermfg=white ctermbg=blue cterm=bold
  hi PmenuSbar ctermfg=white ctermbg=white cterm=NONE
  hi PmenuSel ctermfg=white ctermbg=blue cterm=NONE
  hi PmenuThumb ctermfg=blue ctermbg=blue cterm=NONE
  hi PreProc ctermfg=darkcyan ctermbg=NONE cterm=NONE
  hi Question ctermfg=green ctermbg=NONE cterm=NONE
  hi QuickFixLine ctermfg=magenta ctermbg=black cterm=reverse
  hi Search ctermfg=cyan ctermbg=black cterm=reverse
  hi SignColumn ctermfg=darkcyan ctermbg=NONE cterm=NONE
  hi Special ctermfg=green ctermbg=NONE cterm=NONE
  hi SpecialKey ctermfg=darkgray ctermbg=NONE cterm=NONE
  hi SpellBad ctermfg=red ctermbg=NONE cterm=underline
  hi SpellCap ctermfg=green ctermbg=NONE cterm=underline
  hi SpellLocal ctermfg=white ctermbg=NONE cterm=underline
  hi SpellRare ctermfg=magenta ctermbg=NONE cterm=underline
  hi Statement ctermfg=magenta ctermbg=NONE cterm=NONE
  hi StatusLine ctermfg=white ctermbg=black cterm=reverse
  hi StatusLineNC ctermfg=darkgray ctermbg=gray cterm=bold,reverse
  hi Title ctermfg=NONE ctermbg=NONE cterm=NONE
  hi TitleBar ctermfg=white ctermbg=black cterm=NONE
  hi TitleBarNC ctermfg=gray ctermbg=black cterm=NONE
  hi Todo ctermfg=NONE ctermbg=NONE cterm=reverse
  hi ToolbarButton ctermfg=white ctermbg=darkgray cterm=NONE
  hi ToolbarLine ctermfg=NONE ctermbg=NONE cterm=NONE
  hi Type ctermfg=red ctermbg=NONE cterm=NONE
  hi Underlined ctermfg=NONE ctermbg=NONE cterm=underline
  hi VertSplit ctermfg=blue ctermbg=NONE cterm=NONE
  hi Visual ctermfg=black ctermbg=darkcyan cterm=NONE
  hi VisualNOS ctermfg=black ctermbg=white cterm=NONE
  hi WarningMsg ctermfg=magenta ctermbg=NONE cterm=NONE
  hi WildMenu ctermfg=white ctermbg=blue cterm=NONE
  hi debugBreakpoint ctermfg=green ctermbg=darkblue cterm=reverse
  hi debugPC ctermfg=cyan ctermbg=darkblue cterm=reverse
  finish
endif

if s:t_Co >= 0
  hi CurSearch term=reverse
  hi CursorLineFold term=underline
  hi CursorLineNr term=bold
  hi CursorLineSign term=underline
  hi Float term=NONE
  hi Function term=NONE
  hi Number term=NONE
  hi StatusLineTerm term=bold,reverse
  hi StatusLineTermNC term=bold,underline
  hi TabLine term=bold,underline
  hi TabLineFill term=NONE
  hi TabLineSel term=bold,reverse
  hi Terminal term=NONE
  finish
endif

" vim: et ts=8 sw=2 sts=2
